@@ -27,6 +27,8 @@ or the ``api/2.1/jobs/runs/submit``
 """
 from typing import Any, Dict, List, Optional
 
+from requests import exceptions as requests_exceptions
+
 from airflow.exceptions import AirflowException
 from airflow.providers.databricks.hooks.databricks_base import BaseDatabricksHook
 
@@ -333,22 +335,47 @@ class DatabricksHook(BaseDatabricksHook):
 
     def update_repo(self, repo_id: str, json: Dict[str, Any]) -> dict:
         """
+        Updates given Databricks Repos
 
-        :param repo_id:
-        :param json:
-        :return:
+        :param repo_id: ID of Databricks Repos
+        :param json: payload
+        :return: metadata from update
         """
         repos_endpoint = ('PATCH', f'api/2.0/repos/{repo_id}')
         return self._do_api_call(repos_endpoint, json)
 
-    def get_repo_by_path(self, path: str) -> Optional[str]:
+    def delete_repo(self, repo_id: str):
         """
+        Deletes given Databricks Repos
 
-        :param path:
+        :param repo_id: ID of Databricks Repos
         :return:
         """
-        result = self._do_api_call(WORKSPACE_GET_STATUS_ENDPOINT, {'path': path})
-        if result.get('object_type', '') == 'REPO':
-            return str(result['object_id'])
+        repos_endpoint = ('DELETE', f'api/2.0/repos/{repo_id}')
+        self._do_api_call(repos_endpoint)
+
+    def create_repo(self, json: Dict[str, Any]) -> dict:
+        """
+        Creates a Databricks Repos
+
+        :param json: payload
+        :return:
+        """
+        repos_endpoint = ('POST', 'api/2.0/repos')
+        return self._do_api_call(repos_endpoint, json)
+
+    def get_repo_by_path(self, path: str) -> Optional[str]:
+        """
+        Obtains Repos ID by path
+        :param path: path to a repository
+        :return: Repos ID if it exists, None if doesn't.
+        """
+        try:
+            result = self._do_api_call(WORKSPACE_GET_STATUS_ENDPOINT, {'path': path}, wrap_http_errors=False)
+            if result.get('object_type', '') == 'REPO':
+                return str(result['object_id'])
+        except requests_exceptions.HTTPError as e:
+            if e.response.status_code != 404:
+                raise e
 
         return None
